==> root-debug-6.36.04-6-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/graf3d/x3d/G__X3d.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__X3d
#define R__NO_DEPRECATION

/*******************************************************************/
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "TViewerX3D.h"
#include "TX3DFrame.h"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   static void delete_TViewerX3D(void *p);
   static void deleteArray_TViewerX3D(void *p);
   static void destruct_TViewerX3D(void *p);
   static void streamer_TViewerX3D(TBuffer &buf, void *obj);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TViewerX3D*)
   {
      ::TViewerX3D *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TViewerX3D >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TViewerX3D", ::TViewerX3D::Class_Version(), "TViewerX3D.h", 34,
                  typeid(::TViewerX3D), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TViewerX3D::Dictionary, isa_proxy, 16,
                  sizeof(::TViewerX3D) );
      instance.SetDelete(&delete_TViewerX3D);
      instance.SetDeleteArray(&deleteArray_TViewerX3D);
      instance.SetDestructor(&destruct_TViewerX3D);
      instance.SetStreamerFunc(&streamer_TViewerX3D);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TViewerX3D*)
   {
      return GenerateInitInstanceLocal(static_cast<::TViewerX3D*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TViewerX3D*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

//______________________________________________________________________________
atomic_TClass_ptr TViewerX3D::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TViewerX3D::Class_Name()
{
   return "TViewerX3D";
}

//______________________________________________________________________________
const char *TViewerX3D::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TViewerX3D*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TViewerX3D::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TViewerX3D*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TViewerX3D::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TViewerX3D*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TViewerX3D::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TViewerX3D*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
void TViewerX3D::Streamer(TBuffer &R__b)
{
   // Stream an object of class TViewerX3D.

   TVirtualViewer3D::Streamer(R__b);
}

namespace ROOT {
   // Wrapper around operator delete
   static void delete_TViewerX3D(void *p) {
      delete (static_cast<::TViewerX3D*>(p));
   }
   static void deleteArray_TViewerX3D(void *p) {
      delete [] (static_cast<::TViewerX3D*>(p));
   }
   static void destruct_TViewerX3D(void *p) {
      typedef ::TViewerX3D current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
   // Wrapper around a custom streamer member function.
   static void streamer_TViewerX3D(TBuffer &buf, void *obj) {
      ((::TViewerX3D*)obj)->::TViewerX3D::Streamer(buf);
   }
} // end of namespace ROOT for class ::TViewerX3D

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libX3d() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libX3d) = RecordReadRules_libX3d();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libX3d));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libX3d_Impl() {
    static const char* headers[] = {
"TViewerX3D.h",
"TX3DFrame.h",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/usr/include/freetype2",
"/usr/include",
"/usr/include/freetype2",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = R"DICTFWDDCLS(
#line 1 "libX3d dictionary forward declarations' payload"
#pragma clang diagnostic ignored "-Wkeyword-compat"
#pragma clang diagnostic ignored "-Wignored-attributes"
#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
extern int __Cling_AutoLoading_Map;
class __attribute__((annotate("$clingAutoload$TViewerX3D.h")))  TViewerX3D;
)DICTFWDDCLS";
    static const char* payloadCode = R"DICTPAYLOAD(
#line 1 "libX3d dictionary payload"

#ifndef ROOT_SUPPORT_CLAD
  #define ROOT_SUPPORT_CLAD 1
#endif

#define _BACKWARD_BACKWARD_WARNING_H
// Inline headers
#include "TViewerX3D.h"
#include "TX3DFrame.h"

#undef  _BACKWARD_BACKWARD_WARNING_H
)DICTPAYLOAD";
    static const char* classesHeaders[] = {
"TViewerX3D", payloadCode, "@",
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libX3d",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libX3d_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libX3d_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libX3d() {
  TriggerDictionaryInitialization_libX3d_Impl();
}

==> root-debug-6.38.00-1-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/graf3d/x3d/G__X3d.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__X3d
#define R__NO_DEPRECATION

/*******************************************************************/
#include <cstddef>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "TViewerX3D.h"
#include "TX3DFrame.h"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   static void delete_TViewerX3D(void *p);
   static void deleteArray_TViewerX3D(void *p);
   static void destruct_TViewerX3D(void *p);
   static void streamer_TViewerX3D(TBuffer &buf, void *obj);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TViewerX3D*)
   {
      ::TViewerX3D *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TViewerX3D >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TViewerX3D", ::TViewerX3D::Class_Version(), "TViewerX3D.h", 34,
                  typeid(::TViewerX3D), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TViewerX3D::Dictionary, isa_proxy, 16,
                  sizeof(::TViewerX3D) );
      instance.SetDelete(&delete_TViewerX3D);
      instance.SetDeleteArray(&deleteArray_TViewerX3D);
      instance.SetDestructor(&destruct_TViewerX3D);
      instance.SetStreamerFunc(&streamer_TViewerX3D);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TViewerX3D*)
   {
      return GenerateInitInstanceLocal(static_cast<::TViewerX3D*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TViewerX3D*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

//______________________________________________________________________________
atomic_TClass_ptr TViewerX3D::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TViewerX3D::Class_Name()
{
   return "TViewerX3D";
}

//______________________________________________________________________________
const char *TViewerX3D::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TViewerX3D*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TViewerX3D::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TViewerX3D*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TViewerX3D::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TViewerX3D*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TViewerX3D::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TViewerX3D*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
void TViewerX3D::Streamer(TBuffer &R__b)
{
   // Stream an object of class TViewerX3D.

   TVirtualViewer3D::Streamer(R__b);
}

namespace ROOT {
   // Wrapper around operator delete
   static void delete_TViewerX3D(void *p) {
      delete (static_cast<::TViewerX3D*>(p));
   }
   static void deleteArray_TViewerX3D(void *p) {
      delete [] (static_cast<::TViewerX3D*>(p));
   }
   static void destruct_TViewerX3D(void *p) {
      typedef ::TViewerX3D current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
   // Wrapper around a custom streamer member function.
   static void streamer_TViewerX3D(TBuffer &buf, void *obj) {
      ((::TViewerX3D*)obj)->::TViewerX3D::Streamer(buf);
   }
} // end of namespace ROOT for class ::TViewerX3D

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libX3d() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libX3d) = RecordReadRules_libX3d();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libX3d));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libX3d_Impl() {
    static const char* headers[] = {
"TViewerX3D.h",
"TX3DFrame.h",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = R"DICTFWDDCLS(
#line 1 "libX3d dictionary forward declarations' payload"

#pragma diagnostic push
#pragma clang diagnostic ignored "-Wkeyword-compat"
#pragma clang diagnostic ignored "-Wignored-attributes"
#pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
extern int __Cling_AutoLoading_Map;
class  __attribute__((annotate("$clingAutoload$TViewerX3D.h")))  TViewerX3D;
#pragma diagnostic pop
)DICTFWDDCLS";
    static const char* payloadCode = R"DICTPAYLOAD(
#line 1 "libX3d dictionary payload"

#ifndef ROOT_SUPPORT_CLAD
  #define ROOT_SUPPORT_CLAD 1
#endif
#ifndef R__DUMMY_CXX_STANDARD_17
  #define R__DUMMY_CXX_STANDARD_17 1
#endif

#define _BACKWARD_BACKWARD_WARNING_H
// Inline headers
#include "TViewerX3D.h"
#include "TX3DFrame.h"

#undef  _BACKWARD_BACKWARD_WARNING_H
)DICTPAYLOAD";
    static const char* classesHeaders[] = {
"TViewerX3D", payloadCode, "@",
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libX3d",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libX3d_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libX3d_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libX3d() {
  TriggerDictionaryInitialization_libX3d_Impl();
}
